OpenGB

#### B: 0°/0°

#### N1: 0°/0°

#### N2: 0°/0°

# OpenGB Checklist

To ensure your Open Gigabot is set up correctly follow the steps below:

### Filament Loaded?

### Bed Level?

### Quick Upload

### Swap Material

# OpenGB Control

### Head movement

### WiFi

### Date/Time

# OpenGB Print

### Filename

### Size

Test_print.gco
121KB
Plane.gco
280KB
Teapot.gco
499KB
Shifting_spanner.gco
349KB
Spare_part_1.gco
93KB

# OpenGB Statistics

# OpenGB Help